%global debug_package %{nil}

Name: matterircd
License: MIT
Group: Applications/Internet
Summary: Minimal IRC server which integrates with mattermost
Version: 0.11.2
Release: 5%{?dist}
URL: https://github.com/42wim/matterircd
Packager: Jaroslaw Polok <jaroslaw.polok@cern.ch>
Vendor: CERN, http://cern.ch/linux
Source0: https://github.com/42wim/%{name}/archive/v%{version}.tar.gz#/%{name}-v%{version}.tar.gz
Patch1:  %{name}-v%{version}-libpurple.patch
BuildRoot: %{_tmppath}/%{name}-%{version}-build
BuildRequires: tar
BuildRequires: golang-bin >= 1.6.3

%description
Minimal IRC server which integrates with mattermost

Features:

    support direct messages / private channels
    auto-join/leave to same channels as on mattermost
    reconnects with backoff on mattermost restarts
    support multiple users
    support channel backlog (messages when you're disconnected from IRC/mattermost)
    search messages (/msg mattermost search query)
    scrollback support (/msg mattermost scrollback #channel limit)
    restrict to specified mattermost instances
    set default team/server
    WHOIS, WHO, JOIN, LEAVE, NICK, LIST, ISON, PRIVMSG, MODE, TOPIC, LUSERS, AWAY support
    support TLS (ssl)
    support LDAP logins (mattermost enterprise) (use your ldap account/pass to login)
    &users channel that contains members of all teams (if mattermost is so configured) for easy messaging
    supports mattermost roles (shows admins with @ status for now)
    gitlab auth hack by using mmtoken cookie (see https://github.com/42wim/matterircd/issues/29)


%post
if [ $1 -eq 1 ] ; then 
        # Initial installation
	systemctl preset matterircd.service >/dev/null 2>&1 || :
fi

%preun
if [ $1 -eq 0 ] ; then 
        # Package removal, not upgrade 
        systemctl --no-reload disable matterircd.service >/dev/null 2>&1 || :
fi

%postun
systemctl daemon-reload >/dev/null 2>&1 || :
if [ $1 -ge 1 ] ; then 
        # Package upgrade, not uninstall 
        systemctl restart matterircd.service >/dev/null 2>&1 || : 
fi

%files
#defattr(0755,root,root,-)
%doc LICENSE README.md
%{_sbindir}/%{name}
%{_sbindir}/%{name}-server
%dir /var/log/%{name}/
%config(noreplace)/etc/sysconfig/%{name}
/usr/lib/systemd/system/%{name}.service
/etc/logrotate.d/%{name}

%prep
%setup -q -n %{name}-%{version}
#patch1 -p1

mkdir -p build/{bin,pkg}
cd build/
ln -s ../vendor src
cd -

%build
export GOPATH=`pwd`/build
go build -o bin/%{name}

cat >> %{name}.service << EOF
[Unit]
Description=%{name} server
After=network.target

[Service]
Type=forking
PIDFile=/var/run/%{name}.pid
EnvironmentFile=/etc/sysconfig/%{name}
ExecStart=/usr/sbin/%{name}-server
ExecReload=/usr/bin/kill -HUP \`/bin/cat /var/run/matterircd.pid\`
ExecStop=/usr/bin/kill -9 \`/bin/cat /var/run/matterircd.pid\`
KillMode=process
Restart=on-failure
RestartSec=30
EOF

cat >> %{name}-server << EOF
#!/bin/bash
[ -f /etc/sysconfig/%{name} ] && . /etc/sysconfig/%{name}
[ -z \$MATTERIRCD_OPTIONS ] && MATTERIRCD_OPTIONS=""
/usr/sbin/%{name} \$MATTERIRCD_OPTIONS >> /var/log/%{name}/%{name}.log 2>&1 &
echo \$! > /var/run/%{name}.pid
EOF

cat >> %{name}.sysconfig << EOF
# matterircd options
#
# warning: --debug will log passwords to /var/log/%{name}/%{name}.log
# OPTIONS="--debug"
#
# see /usr/sbin/%{name} --help for options
#
# default options: bind to localhost port 6667
MATTERIRCD_OPTIONS=""
EOF

cat >> %{name}.logrotate << EOF
/var/log/%{name}/%{name}.log {
	missingok
	weekly
	}
EOF
	
%install

mkdir -p $RPM_BUILD_ROOT%{_sbindir}/
mkdir -p $RPM_BUILD_ROOT/usr/lib/systemd/system/
mkdir -p $RPM_BUILD_ROOT/var/log/%{name}
mkdir -p $RPM_BUILD_ROOT/etc/sysconfig/
mkdir -p $RPM_BUILD_ROOT/etc/logrotate.d/

install -m 755 bin/%{name} $RPM_BUILD_ROOT%{_sbindir}/
install -m 755 %{name}-server $RPM_BUILD_ROOT%{_sbindir}/
install -m 644 %{name}.service $RPM_BUILD_ROOT/usr/lib/systemd/system/
install -m 644 %{name}.sysconfig $RPM_BUILD_ROOT/etc/sysconfig/%{name}
install -m 644 %{name}.logrotate $RPM_BUILD_ROOT/etc/logrotate.d/%{name}

%changelog
* Thu Feb 09 2017 Jaroslaw Polok <Jaroslaw.Polok@cern.ch> - 0.11.2-1
- update to 0.11.2 for mattermost 3.5-3.6 releases.

* Mon Dec 05 2016 Jaroslaw Polok <Jaroslaw.Polok@cern.ch> - 0.10.2-4
- add systemd unit file, startup wrapper
- add libpurple patch

* Mon Dec 05 2016 Jaroslaw Polok <Jaroslaw.Polok@cern.ch> - 0.10.2-2
- add logrotate and sysconfig files.

* Sun Dec 04 2016 Jaroslaw Polok <Jaroslaw.Polok@cern.ch> - 0.10.2-1
- initial release.


